if (!HIS) {
	var HIS = {};
}

HIS.main = function() {
	this._init.apply(this, arguments);
};

HIS.main.prototype = {
	
	_infoList : null,
	_property : null,
	_subjectList : null,
	
	_cons : {
		MAX_ITEM_COUNT			: 300,
		INFO_SELECTOR			: ".info",
		KEY_WORD_SELECTOR		: "#keyword",
		INFO_LIST_SELECTOR		: "#infoList",
		TAG_SELECTOR			: ".tag",
		SEARCH_IMAGE_SELECTOR	: ".searchImage",
		PAGE_TITLE_SELECTOR		: ".pageTitle",
		
	},
	
	_init : function() {
		this._infoList = [];
		this._property = new HIS.property();
		this._initInfoList();
		this._initView();
		this._initListener();
	},
	
	_initInfoList : function() {
		var self = this, workId = self._property.getWorkId(), fileName = self._property.getFileName();
		var subjectList = LinkData.getSubjects(workId, fileName);
		for (var i = 0; i < subjectList.length; i++) {
			var subject = subjectList[i];
			var info = new HIS.info();
			info.setName(LinkData.getObjects(workId, fileName, subject, self._property.getNameProperty())[0]);
			info.setArea(LinkData.getObjects(workId, fileName, subject, self._property.getAreaProperty())[0]);
			info.setAd(LinkData.getObjects(workId, fileName, subject, self._property.getAdProperty())[0]);
			info.setJc(LinkData.getObjects(workId, fileName, subject, self._property.getJcProperty())[0]);
			info.setDate(LinkData.getObjects(workId, fileName, subject, self._property.getDateProperty())[0]);
			info.setEvent(LinkData.getObjects(workId, fileName, subject, self._property.getEventProperty())[0]);
			self._infoList.push(info);
		}
	},
	
	_initView : function() {
	
	},
	
	_initListener : function() {
		this._initPageTitleListener();
		this._initAutoCompleter();
		this._initKeywordListener();
		this._initSearchImageListener();
	},
	
	_initPageTitleListener : function() {
		var self = this;
		$(self._cons.PAGE_TITLE_SELECTOR).click(function() {
			$(self._cons.KEY_WORD_SELECTOR).val("");
			var infoList = self._getInfoListByIndex(1, self._cons.MAX_ITEM_COUNT);
			self._addHtml(infoList);
		});
	},
	
	
	
	_initAutoCompleter : function() {
		var self = this;
		$(self._cons.KEY_WORD_SELECTOR).autocomplete({
			minLength: 1,
			source: function(req, res) {
				var keyword = req.term;
				res(self._getMatchWordListByKeyword(keyword));
			},
			select : function(event, ui) {
				var keyword = ui.item.value;
				var infoList = self._getInfoListByIndex(1, self._cons.MAX_ITEM_COUNT, keyword);
				self._addHtml(infoList, keyword);
			}
		})
	},
	
	_initKeywordListener : function() {
		var self = this;
		$(self._cons.KEY_WORD_SELECTOR).keydown(function(evt) {
			if (evt.which == 13) {
				$(self._cons.KEY_WORD_SELECTOR).autocomplete("close");
				var keyword = $(this).val();
				var infoList = self._getInfoListByIndex(1, self._cons.MAX_ITEM_COUNT, keyword);
				self._addHtml(infoList, keyword);
			}
		});
	},
	
	_initSearchImageListener : function() {
		var self = this;
		$(self._cons.SEARCH_IMAGE_SELECTOR).click(function() {
			$(self._cons.KEY_WORD_SELECTOR).autocomplete("close");
			var keyword = $(self._cons.KEY_WORD_SELECTOR).val();
			var infoList = self._getInfoListByIndex(1, self._cons.MAX_ITEM_COUNT, keyword);
			self._addHtml(infoList, keyword);
		});
	},
	
	_initTagListener : function() {
		var self = this;
		$(self._cons.INFO_LIST_SELECTOR + " " + self._cons.TAG_SELECTOR).unbind("click");
		$(self._cons.INFO_LIST_SELECTOR + " " + self._cons.TAG_SELECTOR).click(function() {
			var keyword = $(this).text().trim();
			$(self._cons.KEY_WORD_SELECTOR).val(keyword);
			var infoList = self._getInfoListByIndex(1, self._cons.MAX_ITEM_COUNT, keyword);
			self._addHtml(infoList, keyword);
		});
	},
	
	
	_addHtml : function(infoList, keyword) {
		var self = this;
		if (infoList.length != 0) {
			var html = self._getContentHtml(infoList, keyword);
			$(self._cons.INFO_LIST_SELECTOR).html(html);
			self._initTagListener();
		} else {
			var html = self._getNotFoundHtml();
			$(self._cons.INFO_LIST_SELECTOR).html(html);
		}
	},
	
	_appendHtml : function(infoList, keyword) {
		var self = this;
		var html = self._getContentHtml(infoList, keyword);
		$(self._cons.INFO_LIST_SELECTOR).append(html);
		self._initTagListener();
	},
	
	
	_getInfoList : function(start, itemCount) {
		var self = this, list = [];
		var workId = self._property.getWorkId(), fileName = self._property.getFileName();
		var sList = self._getSubjectList(start, itemCount);
		for (var i = 0; i < sList.length; i++) {
			var subject = sList[i];
			var info = new HIS.info();
			info.setName(LinkData.getObjects(workId, fileName, subject, self._property.getNameProperty())[0]);
			info.setArea(LinkData.getObjects(workId, fileName, subject, self._property.getAreaProperty())[0]);
			info.setAd(LinkData.getObjects(workId, fileName, subject, self._property.getAdProperty())[0]);
			info.setJc(LinkData.getObjects(workId, fileName, subject, self._property.getJcProperty())[0]);
			info.setDate(LinkData.getObjects(workId, fileName, subject, self._property.getDateProperty())[0]);
   	        info.setEvent(LinkData.getObjects(workId, fileName, subject, self._property.getEventProperty())[0]);
			list.push(info);
		}
		return list;
	},
	
	_getMatchWordListByKeyword : function(keyword) {
		
		var self = this, list = [];
		var infoList = self._getInfoListByIndex(2, self._cons.MAX_ITEM_COUNT, keyword);
		$.each(infoList, function(key, info) {
			if (info.getName().toLowerCase().indexOf(keyword.toLowerCase()) > -1 && $.inArray(info.getName(), list)) {
				list.push(info.getName());
			}
			if (info.getArea().toLowerCase().indexOf(keyword.toLowerCase()) > -1 && $.inArray(info.getArea(), list)) {
				list.push(info.getArea());
			} 
			if (info.getAd().toLowerCase().indexOf(keyword.toLowerCase()) > -1 && $.inArray(info.getAd(), list)) {
				list.push(info.getAd());
			} 
			if (info.getEvent().toLowerCase().indexOf(keyword.toLowerCase()) > -1 && $.inArray(info.getEvent(), list)) {
				list.push(info.getEvent());
			}
			if (info.getJc().toLowerCase().indexOf(keyword.toLowerCase()) > -1 && $.inArray(info.getJc(), list)) {
				list.push(info.getJc());
			}
            if (info.getDate().toLowerCase().indexOf(keyword.toLowerCase()) > -1 && $.inArray(info.getDate(), list)) {
				list.push(info.getDate());
			}
		});
		return list;
	},
	
	_getInfoListByIndex : function(page, itemCount, keyword) {
		var self = this, list = [], count = 0;
		var end = (page * itemCount) - 1;
		var start = end - itemCount + 1;
		for (var i = 0; i < self._infoList.length; i++) {
			var info = self._infoList[i];
			if ((!keyword || keyword.trim().length == 0) || self._isHitInfo(info, keyword)) {
				if (count >= start && count <= end) {
					list.push(info);
				}
				count++;
			}
			if (list.length == itemCount) {
				return list;
			}
		}
		return list;
	},
	
	_isHitInfo : function(info, keyword) {
		if (!keyword || keyword.trim().length == 0) {
			return false;
		}
		if (info.getName().toLowerCase().indexOf(keyword.toLowerCase()) > -1) {
			return true;
		} else if (info.getArea().toLowerCase().indexOf(keyword.toLowerCase()) > -1) {
			return true;
		} else if (info.getAd().toLowerCase().indexOf(keyword.toLowerCase()) > -1) {
			return true;
		} else if (info.getEvent().toLowerCase().indexOf(keyword.toLowerCase()) > -1) {
			return true;
		} else if (info.getJc().toLowerCase().indexOf(keyword.toLowerCase()) > -1) {
			return true;
		} else if (info.getDate().toLowerCase().indexOf(keyword.toLowerCase()) > -1) {
			return true;
		}
		return false;
	},
	
	_getContentHtml : function(infoList, keyword) {/* 情報ウィンドの表示設定 */
		var self = this, sb = [];
		for (var i = 0; i < infoList.length; i++) {
			var info = infoList[i];
			sb[sb.length] = "<div class='info cf'>";
			sb[sb.length] = "<div class='profileInfoArea left'>";
			sb[sb.length] = ""+"<div class='name'>▼" +self._getHighLightKeywordHtml(info.getArea(), keyword) + "の出来事▼<br>" + self._getHighLightKeywordHtml(info.getAd(), keyword) + "年（" + self._getHighLightKeywordHtml(info.getJc(), keyword)  +"年）　" + self._getHighLightKeywordHtml(info.getDate(), keyword);
			if (info.getEvent().trim().length != 0) {
				sb[sb.length] = "<br><span class='nextTo'>" + self._getHighLightKeywordHtml(info.getEvent(), keyword) + "</span>";
			}
　　　　　　　
			sb[sb.length] = "</div>";
			sb[sb.length] = "<div class='cf'>";
			sb[sb.length] = "</div>";
			sb[sb.length] = "</div>";
			sb[sb.length] = "</div>";
			sb[sb.length] = "</div>";
		}
		return sb.join("");
	},
	
	_getHighLightKeywordHtml : function(text, keyword) {
		if (!keyword || keyword.trim().length == 0) {
			return text;
		}
		var regex = new RegExp('(' + keyword + ')', 'gi');
		return text.replace(regex, "<span class='highlight'>$1</span>");
	},
	
	_getNotFoundHtml : function() {
		var sb = [];
		sb[sb.length] = "<div class='info error'>出来事は見つかりませんでした</div>";
		return sb.join("");
	},
	
	_getTagListHtml : function(tagList, keyword) {
		var self = this, sb = [];
		for (var i = 0; i < tagList.length; i++) {
			var tag = tagList[i];
			sb[sb.length] = "<span class='tag left'>" + self._getHighLightKeywordHtml(tag.trim(), keyword) + "</span>";
		}
		return sb.join("");
	}
};

HIS.property = function() {
	this._init.apply(this, arguments);
};

HIS.property.prototype = {
	
	_workId : null,
	_fileName : null,
	_nameProperty : null,
	_areaProperty : null,
	_adProperty : null,
	_jcProperty : null,
	_dateProperty : null,
	_eventProperty : null,


	_cons : {
		NAME			: "label",
		AREA			: "area",
		AD				: "ad",
		DATE			: "date",
		JC				: "jc",
		EVENT			: "event"

	},
	
	_init : function() {
		this._initProperty();
	},
	
	_initProperty : function() {
		var self = this;
		$.each(LinkData.getWorks(), function(workKey, workId) {
			$.each(LinkData.getFiles(workId), function(fileKey, fileName) {
				self._workId = workId;
				self._fileName = fileName;
				$.each(LinkData.getProperties(workId, fileName), function(propKey, propValue) {
					if (propValue.indexOf(self._cons.NAME) > -1) {
						self._nameProperty = propValue;
					} else if (propValue.indexOf(self._cons.AREA) > -1) {
						self._areaProperty = propValue;
					} else if (propValue.indexOf(self._cons.AD) > -1) {
						self._adProperty = propValue;
					} else if (propValue.indexOf(self._cons.JC) > -1) {
						self._jcProperty = propValue;
					} else if (propValue.indexOf(self._cons.DATE) > -1) {
						self._dateProperty = propValue;
					} else if (propValue.indexOf(self._cons.EVENT) > -1) {
						self._eventProperty = propValue;
					}
				});
				return false;
			});
			return false;
		});
	},
	
	getWorkId : function() {
		return this._workId;
	},
	
	getFileName : function() {
		return this._fileName;
	},
	
	getNameProperty : function() {
		return this._nameProperty;
	},
	
	getAreaProperty : function() {
		return this._areaProperty;
	},
	
	getAdProperty : function() {
		return this._adProperty;
	},
	
	getJcProperty : function() {
		return this._jcProperty;
	},
	
	getDateProperty : function() {
		return this._dateProperty;
	},
	
	getEventProperty : function() {
		return this._eventProperty;

	}
};

HIS.info = function() {
	this._init.apply(this, arguments);
};

HIS.info.prototype = {
	_name : null,
	_area : null,
	_ad : null,
	_jc : null,
	_date : null,
	_event : null,

	_init : function() {},
	
	getName : function() {
		if (!this._name) {
			this._name = "";
		}
		return this._name;
	},
	
	setName : function(name) {
		this._name = name;
	},
	
	getArea : function() {
		if (!this._area) {
			this._area = "";
		}
		return this._area;
	},
	
	setArea : function(area) {
		this._area = area;
	},
	
	getAd : function() {
		if (!this._ad) {
			this._ad = "";
		}
		return this._ad;
	},
	
	setAd : function(ad) {
		this._ad = ad;
	},
	
	getJc : function() {
		if (!this._jc) {
			this._jc = "";
		}
		return this._jc;
	},
	
	setJc : function(jc) {
		this._jc = jc;
	},
	
	getDate : function() {
		if (!this._date) {
			this._date = "";
		}
		return this._date;
	},
	
	setDate : function(date) {
		this._date = date;
	},
	
	getEvent : function() {
		if (!this._event) {
			this._event = "";
		}
		return this._event;
	},
	
	setEvent : function(event) {
		this._event = event;
	}
	
	

};

$(document).ready(function() {
	new HIS.main();
});
